@@ -2,7 +2,7 @@
 Class object for AudioPutPayload and AudioPutResponse
 Documentation: https://system-bridge.timmo.dev
 """
-from typing import Optional, Union
+from __future__ import annotations
 
 from . import Audio
 from ..base import BridgeBase
@@ -10,11 +10,11 @@ from ..base import BridgeBase
 
 class AudioPutPayload(BridgeBase):
     @property
-    def value(self) -> Union[bool, float]:
+    def value(self) -> bool | float | None:
         return self.attributes.get("value", True)
 
 
 class AudioPutResponse(Audio):
     @property
-    def successful(self) -> Optional[bool]:
+    def successful(self) -> bool | None:
         return self.attributes.get("successful", False)
